==> openjdk-17_17.0.17+10.orig.tar.xz: openjdk-17-17.0.17+10/test/micro/org/openjdk/bench/vm/compiler/InnerClassNullRef.java <==
/*
 * Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.openjdk.bench.vm.compiler;

import org.openjdk.jmh.annotations.Benchmark;
import org.openjdk.jmh.annotations.BenchmarkMode;
import org.openjdk.jmh.annotations.Mode;
import org.openjdk.jmh.annotations.OutputTimeUnit;
import org.openjdk.jmh.annotations.Scope;
import org.openjdk.jmh.annotations.Setup;
import org.openjdk.jmh.annotations.State;

import java.util.concurrent.TimeUnit;

@BenchmarkMode(Mode.AverageTime)
@OutputTimeUnit(TimeUnit.NANOSECONDS)
@State(Scope.Thread)
public class InnerClassNullRef {

    class Pickles {
        int count;

        public Pickles(int x) {
            count = x;
        }

        public int getCount() {
            return count;
        }

        public void setCount(int x) {
            count = x;
        }
    }

    class BurgerStand {
        public void makeBurgers() {
            if (pickles != null) {
                // add a pickle
                pickles.setCount(pickles.getCount() - 1);
            }
        }
    }

    class BurgerStandNull {
        public void makeBurgers() {
            if (picklesNull != null) {
                // add a pickle
                picklesNull.setCount(picklesNull.getCount() - 1);
            }
        }
    }

    private BurgerStand bs;
    private BurgerStandNull bsNull;
    private Pickles pickles;
    private Pickles picklesNull;

    @Setup
    public void setup() {
        bs = new BurgerStand();
        bsNull = new BurgerStandNull();
        pickles = new Pickles(42);
    }

    @Benchmark
    public void refIsNull() {
        bsNull.makeBurgers();
    }

    @Benchmark
    public void refIsNotNull() {
        bs.makeBurgers();
    }
}

==> openjdk-21_21.0.9+10.orig.tar.xz: openjdk-21-21.0.9+10/test/micro/org/openjdk/bench/vm/compiler/InnerClassNullRef.java <==
/*
 * Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.openjdk.bench.vm.compiler;

import org.openjdk.jmh.annotations.Benchmark;
import org.openjdk.jmh.annotations.BenchmarkMode;
import org.openjdk.jmh.annotations.Fork;
import org.openjdk.jmh.annotations.Measurement;
import org.openjdk.jmh.annotations.Mode;
import org.openjdk.jmh.annotations.OutputTimeUnit;
import org.openjdk.jmh.annotations.Scope;
import org.openjdk.jmh.annotations.Setup;
import org.openjdk.jmh.annotations.State;
import org.openjdk.jmh.annotations.Warmup;

import java.util.concurrent.TimeUnit;

@BenchmarkMode(Mode.AverageTime)
@OutputTimeUnit(TimeUnit.NANOSECONDS)
@State(Scope.Thread)
@Warmup(iterations = 4, time = 2, timeUnit = TimeUnit.SECONDS)
@Measurement(iterations = 4, time = 2, timeUnit = TimeUnit.SECONDS)
@Fork(value = 3)
public class InnerClassNullRef {

    class Pickles {
        int count;

        public Pickles(int x) {
            count = x;
        }

        public int getCount() {
            return count;
        }

        public void setCount(int x) {
            count = x;
        }
    }

    class BurgerStand {
        public void makeBurgers() {
            if (pickles != null) {
                // add a pickle
                pickles.setCount(pickles.getCount() - 1);
            }
        }
    }

    class BurgerStandNull {
        public void makeBurgers() {
            if (picklesNull != null) {
                // add a pickle
                picklesNull.setCount(picklesNull.getCount() - 1);
            }
        }
    }

    private BurgerStand bs;
    private BurgerStandNull bsNull;
    private Pickles pickles;
    private Pickles picklesNull;

    @Setup
    public void setup() {
        bs = new BurgerStand();
        bsNull = new BurgerStandNull();
        pickles = new Pickles(42);
    }

    @Benchmark
    public void refIsNull() {
        bsNull.makeBurgers();
    }

    @Benchmark
    public void refIsNotNull() {
        bs.makeBurgers();
    }
}
